==> wallet-adapter-react-0.2.8.tgz: package/src/providers/Provider.tsx <==
// import '../style.css';

import React, { useMemo } from 'react';

import {
  ConnectionProvider,
  WalletProvider,
} from '@solana/wallet-adapter-react';

import { E2EWalletAdapter, E2EWalletAdapterConfig } from '../adapters/e2e';
import { DemonWalletAdapter } from '../adapters/index';
import {
  getNetworkUrls,
} from '../helpers';
import {
  WalletModalProvider,
  type WalletModalProviderProps,
} from './WalletModalProvider';

export interface WalletUIProviderProps extends WalletModalProviderProps {
  isMainnet: boolean,
  e2e?: boolean,
  e2eWalletAdapterConfig?: E2EWalletAdapterConfig
}

export const Provider = ({
  children,
  isMainnet,
  e2e,
  e2eWalletAdapterConfig,
  ...modalProviderProps
}: WalletUIProviderProps) => {
  const wallets = useMemo(() => {
    const supportedWallets = []
    if (e2e) {
      supportedWallets.push(new E2EWalletAdapter(e2eWalletAdapterConfig))
    } else {
      supportedWallets.push(new DemonWalletAdapter())
    }

    return supportedWallets
  }, [e2e, e2eWalletAdapterConfig])

  const urls = useMemo(() => getNetworkUrls(isMainnet), [])

  return (
    <ConnectionProvider
      endpoint={urls.rpc}
      config={{
        wsEndpoint: urls.wss,
        commitment: 'confirmed',
      }}
    >
      <WalletProvider
        wallets={wallets}
        autoConnect
      >
        <WalletModalProvider
          {...modalProviderProps}
        >
          {children}
        </WalletModalProvider>
      </WalletProvider>
    </ConnectionProvider>
  )
}

==> wallet-adapter-react-0.2.9.tgz: package/src/providers/Provider.tsx <==
// import '../style.css';

import React, { useMemo } from 'react';

import bs58 from 'bs58';

import {
  ConnectionProvider,
  WalletProvider,
} from '@solana/wallet-adapter-react';
import { Keypair } from '@solana/web3.js';

import { E2EWalletAdapter } from '../adapters/e2e';
import { DemonWalletAdapter } from '../adapters/index';
import {
  getNetworkUrls,
  isRunningInCypress,
} from '../helpers';
import {
  WalletModalProvider,
  type WalletModalProviderProps,
} from './WalletModalProvider';

export interface WalletUIProviderProps extends WalletModalProviderProps {
  isMainnet: boolean,
  e2eWalletPrivKey?: string,
  endpoint?: {
    rpc: string,
    wss: string,
  },
}

export const Provider = ({
  children,
  isMainnet,
  e2eWalletPrivKey,
  endpoint,
  ...modalProviderProps
}: WalletUIProviderProps) => {
  const wallets = useMemo(() => {
    const supportedWallets = []
    if (isRunningInCypress) {
      if (e2eWalletPrivKey) {
        supportedWallets.push(
          // @ts-ignore
          new E2EWalletAdapter({
            keypair: Keypair.fromSecretKey(bs58.decode(e2eWalletPrivKey))
          }),
        )
      }
      // // @ts-ignore
      // supportedWallets.push(new E2EWalletAdapter())
    } else {
      supportedWallets.push(new DemonWalletAdapter())
    }

    return supportedWallets
  }, [])

  const urls = useMemo(() => endpoint || getNetworkUrls(isMainnet), [])

  return (
    <ConnectionProvider
      endpoint={urls.rpc}
      config={{
        wsEndpoint: urls.wss,
        commitment: 'confirmed',
      }}
    >
      <WalletProvider
        wallets={wallets}
        autoConnect
      >
        <WalletModalProvider
          {...modalProviderProps}
        >
          {children}
        </WalletModalProvider>
      </WalletProvider>
    </ConnectionProvider>
  )
}
